@@ -23,7 +23,13 @@ def test_plan_config(plan_config):
         "target_arch": "i386",
         "toolchain": "gcc-8",
     }
-    assert cfg.plan[0]["tests"] == [{"device": "qemu-i386", "tests": ["ltp-smoke"]}]
+    assert cfg.plan[0]["tests"] == [
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-smoke"],
+            "rootfs": "https://example.com/rootfs.ext4.zst",
+        }
+    ]
 
     assert cfg.plan[1]["build"] == {
         "kconfig": "tinyconfig",
@@ -142,6 +148,18 @@ def test_plan_config(plan_config):
     ]
 
 
+def test_bake_plan_config(bake_plan_config):
+    cfg = PlanConfig("", "", bake_plan_config)
+    assert cfg.name == "armv7 validation"
+    assert cfg.description == "Build and test linux kernel for armv7"
+
+    cfg = PlanConfig("hello", "world", bake_plan_config)
+    assert cfg.name == "hello"
+    assert cfg.description == "world"
+
+    assert len(cfg.plan) == 3
+
+
 def test_plan_config_job_name(plan_config):
     cfg = PlanConfig("hello", "world", plan_config, "gcc-simple")
     assert len(cfg.plan) == 0
@@ -155,6 +173,16 @@ def test_plan_config_job_name(plan_config):
     }
 
 
+def test_bake_plan_config_job_name(bake_plan_config):
+    cfg = PlanConfig("hello", "world", bake_plan_config)
+    assert len(cfg.plan) == 3
+
+    cfg = PlanConfig("hello", "world", bake_plan_config, "armv7")
+    assert len(cfg.plan) == 1
+    assert cfg.plan[0]["build"]["machine"] == "ledge-multi-armv7"
+    assert not cfg.plan[0]["tests"]
+
+
 def test_plan_config_version(plan_config_unknown_version):
     with pytest.raises(InvalidConfiguration):
         PlanConfig("hello", "world", plan_config_unknown_version, "gcc-simple")
@@ -168,6 +196,7 @@ def test_submit(config, plan_config, mocker):
         git_ref="master",
         group="tuxgrp",
         project="tuxprj",
+        no_cache=True,
     )
 
     def post(url, headers, data):
@@ -206,6 +235,7 @@ def test_submit(config, plan_config, mocker):
                 assert t["device"] == d["device"]
                 assert t.get("kernel") == d.get("kernel")
                 assert t.get("tests") == d.get("tests")
+                assert t.get("rootfs") == d.get("rootfs")
 
             assert data[0]["waiting_for"] == "my-build-00"
             assert data[1]["waiting_for"] == "my-build-01"
@@ -239,6 +269,55 @@ def test_submit(config, plan_config, mocker):
     assert len(plan.tests) == 21
 
 
+def test_bake_submit(config, bake_plan_config, mocker):
+    cfg = PlanConfig("", "", bake_plan_config)
+    plan = Plan(
+        cfg,
+        group="bake_tuxgrp",
+        project="bake_tuxprj",
+        local_manifest="https://gitlab.com/alok.ranjan1/test-project/-/blob/main/default.xml",
+    )
+
+    def post(url, headers, data):
+        assert "Authorization" in headers
+        if (
+            url
+            == "https://tuxapi.tuxsuite.com/v1/groups/bake_tuxgrp/projects/bake_tuxprj/plans"
+        ):
+            assert data == {
+                "name": "armv7 validation",
+                "description": "Build and test linux kernel for armv7",
+            }
+            return {"uid": "my-plan-uid"}
+        if (
+            url
+            == "https://tuxapi.tuxsuite.com/v1/groups/bake_tuxgrp/projects/bake_tuxprj/oebuilds"
+        ):
+            assert isinstance(data, dict)
+            assert len(data["oebuilds"]) == 3
+            builds = data["oebuilds"]
+            index = 0
+            for p, d in zip(cfg.plan, builds):
+                assert p["build"]["container"] == d["container"]
+                assert p["build"]["distro"] == d["distro"]
+                assert p["build"]["envsetup"] == d["envsetup"]
+                assert p["build"]["machine"] == d["machine"]
+                assert p["build"]["sources"] == d["sources"]
+                assert p["build"]["target"] == d["target"]
+                assert d["plan"] == "my-plan-uid"
+                d["uid"] = f"my-build-{index:02}"
+                d["download_url"] = f"http://url/{d['uid']}"
+                index += 1
+            return builds
+
+        assert 0
+
+    mocker.patch("tuxsuite.build.post_request", post)
+    plan.submit()
+    assert len(plan.builds) == 3
+    assert len(plan.tests) == 0
+
+
 def test_get_plan(config, plan_config, mocker):
     cfg = PlanConfig("", "", plan_config)
     plan = Plan(
@@ -258,10 +337,15 @@ def test_get_plan(config, plan_config, mocker):
             url
             == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/plans/my-1-plan-uid"
         ):
-            assert params == {"start_builds": None, "start_tests": None}
+            assert params == {
+                "start_builds": None,
+                "start_tests": None,
+                "start_oebuilds": None,
+            }
             return {
                 "builds": {"next": None, "results": [], "count": 0},
                 "tests": {"next": None, "results": [], "count": 0},
+                "oebuilds": {"next": None, "results": [], "count": 0},
             }
         if (
             url
@@ -269,7 +353,11 @@ def test_get_plan(config, plan_config, mocker):
         ):
             calls += 1
             if calls == 1:
-                assert params == {"start_builds": None, "start_tests": None}
+                assert params == {
+                    "start_builds": None,
+                    "start_tests": None,
+                    "start_oebuilds": None,
+                }
                 return {
                     "builds": {
                         "next": "next_build",
@@ -281,11 +369,17 @@ def test_get_plan(config, plan_config, mocker):
                         "results": [{"uid": "1"}],
                         "count": 1,
                     },
+                    "oebuilds": {
+                        "next": None,
+                        "results": [],
+                        "count": 0,
+                    },
                 }
             if calls == 2:
                 assert params == {
                     "start_builds": "next_build",
                     "start_tests": "next_test",
+                    "start_oebuilds": None,
                 }
                 return {
                     "builds": {
@@ -296,7 +390,11 @@ def test_get_plan(config, plan_config, mocker):
                     "tests": {"next": None, "results": [{"uid": "2"}], "count": 1},
                 }
             if calls == 3:
-                assert params == {"start_builds": "next_build_bis", "start_tests": None}
+                assert params == {
+                    "start_builds": "next_build_bis",
+                    "start_tests": None,
+                    "start_oebuilds": None,
+                }
                 return {
                     "builds": {"next": None, "results": [{"uid": "3"}], "count": 1},
                     "tests": {"next": None, "results": [{"uid": "3"}], "count": 1},
@@ -315,6 +413,99 @@ def test_get_plan(config, plan_config, mocker):
     }
 
 
+def test_bake_get_plan(config, mocker, bake_plan_config):
+    cfg = PlanConfig("", "", bake_plan_config)
+    plan = Plan(
+        cfg,
+        group="bake_tuxgrp",
+        project="bake_tuxprj",
+    )
+
+    calls = 0
+
+    def get(url, headers, params):
+        nonlocal calls
+        assert "Authorization" in headers
+        if (
+            url
+            == "https://tuxapi.tuxsuite.com/v1/groups/bake_tuxgrp/projects/bake_tuxprj/plans/my-1-bake_plan-uid"
+        ):
+            assert params == {
+                "start_builds": None,
+                "start_tests": None,
+                "start_oebuilds": None,
+            }
+            return {
+                "builds": {"next": None, "results": [], "count": 0},
+                "tests": {"next": None, "results": [], "count": 0},
+                "oebuilds": {"next": None, "results": [], "count": 0},
+            }
+        if (
+            url
+            == "https://tuxapi.tuxsuite.com/v1/groups/bake_tuxgrp/projects/bake_tuxprj/plans/my-2-bake_plan-uid"
+        ):
+            calls += 1
+            if calls == 1:
+                assert params == {
+                    "start_builds": None,
+                    "start_tests": None,
+                    "start_oebuilds": None,
+                }
+                return {
+                    "builds": {
+                        "next": None,
+                        "results": [],
+                        "count": 0,
+                    },
+                    "tests": {
+                        "next": "next_test",
+                        "results": [{"uid": "1"}],
+                        "count": 1,
+                    },
+                    "oebuilds": {
+                        "next": "next_oebuild",
+                        "results": [{"uid": "1"}],
+                        "count": 1,
+                    },
+                }
+            if calls == 2:
+                assert params == {
+                    "start_builds": None,
+                    "start_tests": "next_test",
+                    "start_oebuilds": "next_oebuild",
+                }
+                return {
+                    "oebuilds": {
+                        "next": "next_oebuild_bis",
+                        "results": [{"uid": "2"}],
+                        "count": 1,
+                    },
+                    "tests": {"next": None, "results": [{"uid": "2"}], "count": 1},
+                }
+            if calls == 3:
+                assert params == {
+                    "start_builds": None,
+                    "start_tests": None,
+                    "start_oebuilds": "next_oebuild_bis",
+                }
+                return {
+                    "oebuilds": {"next": None, "results": [{"uid": "3"}], "count": 1},
+                    "tests": {"next": None, "results": [{"uid": "3"}], "count": 1},
+                }
+        assert 0
+
+    plan.plan = "my-1-bake_plan-uid"
+    mocker.patch("tuxsuite.build.get_request", get)
+    assert plan.get_plan() == {"tests": {}, "builds": {}}
+
+    plan.plan = "my-2-bake_plan-uid"
+    mocker.patch("tuxsuite.build.get_request", get)
+    assert plan.get_plan() == {
+        "builds": {"1": {"uid": "1"}, "2": {"uid": "2"}, "3": {"uid": "3"}},
+        "tests": {"1": {"uid": "1"}, "2": {"uid": "2"}},
+    }
+
+
 def test_watch(config, mocker, plan_config):
     mocker.patch("time.sleep")
     build_attrs = {
@@ -464,6 +655,99 @@ def test_watch(config, mocker, plan_config):
     assert states[13].state == "finished"
 
 
+def test_bake_watch(config, mocker, bake_plan_config):
+    mocker.patch("time.sleep")
+    # bake plan watch
+    build_attrs = {
+        "group": "bake_tuxgrp",
+        "project": "bake_tuxprj",
+        "token": "test_token",
+        "kbapi_url": "http://test/foo",
+        "tuxapi_url": "http://tuxapi",
+    }
+
+    cfg = PlanConfig("", "", bake_plan_config)
+    plan = Plan(
+        cfg,
+        group="bake_tuxgrp",
+        project="bake_tuxprj",
+    )
+    plan.builds = []
+    uid = 1
+    for cfg in cfg.plan:
+        if cfg["build"]:
+            build_attrs["data"] = cfg["build"]
+            plan.builds.append(
+                tuxsuite.build.Bitbake(**build_attrs, uid=f"bake_build-{uid}")
+            )
+            uid += 1
+
+    count = 0
+
+    def get_bake_plan():
+        nonlocal count
+        count += 1
+        if count == 1:
+            return {
+                "builds": {
+                    "bake_build-1": {"state": "provisioning", "result": "unknown"},
+                    "bake_build-2": {"state": "running", "result": "unknown"},
+                    "bake_build-3": {
+                        "state": "finished",
+                        "result": "pass",
+                        "tuxbuild_status": "pass",
+                        "build_status": "pass",
+                        "warnings_count": 0,
+                    },
+                },
+                "tests": [],
+            }
+        if count == 2:
+            return {
+                "builds": {
+                    "bake_build-1": {
+                        "state": "finished",
+                        "result": "pass",
+                        "tuxbuild_status": "pass",
+                        "build_status": "pass",
+                        "warnings_count": 0,
+                    },
+                    "bake_build-2": {
+                        "state": "finished",
+                        "result": "pass",
+                        "tuxbuild_status": "pass",
+                        "build_status": "pass",
+                        "warnings_count": 0,
+                    },
+                    "bake_build-3": {
+                        "state": "finished",
+                        "result": "pass",
+                        "tuxbuild_status": "pass",
+                        "build_status": "pass",
+                        "warnings_count": 0,
+                    },
+                },
+                "tests": [],
+            }
+        assert 0
+
+    plan.get_plan = get_bake_plan
+    states = list(plan.watch())
+    assert len(states) == 5
+
+    assert states[0].build.uid == "bake_build-1"
+    assert states[0].state == "provisioning"
+    assert states[1].build.uid == "bake_build-2"
+    assert states[1].state == "running"
+    assert states[2].build.uid == "bake_build-3"
+    assert states[2].state == "finished"
+
+    assert states[3].build.uid == "bake_build-1"
+    assert states[3].state == "finished"
+    assert states[4].build.uid == "bake_build-2"
+    assert states[4].state == "finished"
+
+
 def test_config_url(get, response, sample_plan_config):
     response._content = bytes(sample_plan_config, "utf-8")
 
@@ -471,6 +755,16 @@ def test_config_url(get, response, sample_plan_config):
     assert len(cfg.plan) == 12
 
 
+def test_bake_config_url(get, response, sample_bake_plan_config):
+    response._content = bytes(sample_bake_plan_config, "utf-8")
+
+    cfg = PlanConfig("hello", "world", "http://example.com/plan.yaml")
+    assert len(cfg.plan) == 3
+
+    with pytest.raises(InvalidConfiguration):
+        cfg = PlanConfig("hello", "world", "test/alok")
+
+
 def test_fetch_errors(get, response):
     response.status_code = 404
     with pytest.raises(InvalidConfiguration):
