@@ -284,17 +284,17 @@ class Build(HeadersMixin):
 
     def verify_build_parameters(self):
         """Pre-check the build arguments"""
-        assert self.git_repo, "git_repo is mandatory"
+        assert self.git_repo, "git_repo is mandatory\n"
         assert self.is_supported_git_url(
             self.git_repo
-        ), "git url must be in the form of git:// or http:// or https://"
+        ), "git url must be in the form of git:// or http:// or https://\n"
         assert (self.git_ref and not self.git_sha) or (
             self.git_sha and not self.git_ref
-        ), "Either a git_ref or a git_sha is required"
-        assert self.target_arch is not None, "target_arch is mandatory"
-        assert self.kconfig, "kconfig is mandatory"
-        assert self.toolchain, "toolchain is mandatory"
-        assert self.headers is not None, "headers is mandatory"
+        ), "Either a git_ref or a git_sha is required\n"
+        assert self.target_arch is not None, "target-arch is mandatory\n"
+        assert self.kconfig, "kconfig is mandatory\n"
+        assert self.toolchain, "toolchain is mandatory\n"
+        assert self.headers is not None, "headers is mandatory\n"
 
     def build(self, plan=None):
         """Submit the build request"""
