@@ -25,7 +25,7 @@ def handle_submit(cmdargs, _, config):
         )
         sys.exit(1)
     if cmdargs.local_manifest:
-        data["manifest"] = cmdargs.local_manifest.read()
+        data["manifest"] = cmdargs.local_manifest
 
     data["no_cache"] = cmdargs.no_cache
 
